#/bin/bash

sadiag=sadiag.txt

#directory for logs folder of savfl
diag_dir=/var/symantec/sep/Logs/diag
log_dir=${diag_dir}/logs
cfg_dir=${diag_dir}/conf
bin_dir=${diag_dir}/bin
product_root="/opt/Symantec"
NetworkInterfaceTool=""
NetworkStatTool=""
HostnameGetTool=""
lu_debug_prefix=""

begin()
{
	rm -rf "${diag_dir}" > /dev/null 2>&1
	local dirs="${diag_dir} \
				${log_dir} \
				${cfg_dir} \
				${bin_dir} \
				"
	for dir in $dirs
	do
		mkdir -p "${dir}" > /dev/null 2>&1
		if [ ! 0 -eq $? ] ; then
			echo "cannot create ${dir}, err: $?"
			return 1
		fi
	done

	#get product dir.
	if [ -f /etc/Symantec.conf ] ; then
		product_root=$(cat /etc/Symantec.conf | awk -F'=' '$1 == "BaseDir" {print $2}')
	fi
}

finish()
{
	rm -rf "${diag_dir}" > /dev/null 2>&1
	rm -f "./sadiag.txt" > /dev/null 2>&1
}

#$1 process name
core()
{
	local pname="$1"
	if [ "" = "$pname" ] ; then
		return 1
	fi

	local gdb=$(which gdb)
	if [ ! 0 -eq $? -o "" = "$gdb" ] ; then
		echo "gdb cannot be found."
		return 1
	fi

	local pids=$(pidof "${pname}" | xargs)
	for pid in $pids
	do
		echo "generate core file for ${pname}" | tee -a $sadiag
		$gdb --nx -q ${pname} ${pid} -ex "generate-core-file ${bin_dir}/${pname}_${pid}" -ex detach -ex quit >> $sadiag 2>&1
	done

	return 0
}

collectlogs()
{
	echo " " >> $sadiag
	#install
	echo "Collecting install logs for SAVFL..." | tee -a $sadiag
	local installdir="${log_dir}/install"
	if [ ! -d ${installdir} ] ; then
		mkdir $installdir > /dev/null 2>&1
		if [ ! 0 -eq $? ] ; then
			echo "cannot create $installdir, err: $?" >> $sadiag
		fi
	fi

	#Collect the new build installation log files	
	cp -f ~/sep*.log ${installdir}/ > /dev/null 2>&1
	cp -f ~/sep*.log.* ${installdir}/ > /dev/null 2>&1

	#Collect the old build uninstallation log files
	cp -f ~/sav*.log ${installdir}/ > /dev/null 2>&1
	cp -f ~/sav*.log.* ${installdir}/ > /dev/null 2>&1

	echo " " >> $sadiag
	#debug log
	echo "Collecting debug logs for SAVFL..." | tee -a $sadiag
	local debug="${log_dir}/debug"
	if [ ! -d $debug ] ; then
		mkdir $debug > /dev/null 2>&1
		if [ ! 0 -eq $? ] ; then
			echo "cannot create $debug, err: $?" >> $sadiag
		fi
	fi

	local sav_var="/var/symantec/sep/Logs"
	cp -f ${sav_var}/*.log "${debug}/"

	echo " " >> $sadiag
	#liveupdate
	echo "Collecting liveupdate logs for SAVFL..." | tee -a $sadiag
	cp -f "${product_root}/LiveUpdate/Logs/lux.log" "${debug}/"
	
	#liveupdate debug logs
        if [ -f /etc/symantec/lux.logging.conf ] ; then
                lu_debug_prefix=$(cat /etc/symantec/lux.logging.conf | awk -F'=' '$1 == "logger.sink.file.filePath" {print $2}' | awk -F'.' '{print $1}')
		cp -f ${lu_debug_prefix}* "${debug}/"
        fi


	#vpdebug log
	local vpdebugs=$(ls "${product_root}/symantec_antivirus/" | grep ^vpdebug | xargs)
	for vpdebug in $vpdebugs
	do
		cp -f "${product_root}/symantec_antivirus/${vpdebug}" "${debug}/${vpdebug}" >> $sadiag
	done

	return 0
}

collectcfgs()
{
	echo "Collecting configuration files for SAVFL..." | tee -a $sadiag
	local etc_symc="/etc/symantec/sep"
	if [ -d ${etc_symc} ] ; then
		local files=$(ls "${etc_symc}" | xargs)
		for file in $files
		do
			cp -f "${etc_symc}/$file" "${cfg_dir}/$file" >> $sadiag 2>&1
		done
	fi

	cp -f "/etc/Symantec.conf" "${cfg_dir}/"

	cp -f "${product_root}/LiveUpdate/luxds.dat" "${cfg_dir}/"

	local var_symc="/var/symantec/sep"
	if [ -d ${var_symc} ] ; then
		local files=$(ls "${var_symc}" | xargs)
		for file in $files
		do
			cp -f "${var_symc}/$file" "${cfg_dir}/$file" >> $sadiag 2>&1
		done
	fi

	#symcfg data
	local symcfg="${product_root}/symantec_antivirus/symcfg"
	if [ -f $symcfg ] ; then
		$symcfg -r list >> "${cfg_dir}/symcfg.list" 2>&1
	fi

	return 0
}

begin

which ip > /dev/null 2>&1
if [ 0 -eq $? ]; then
    NetworkInterfaceTool="ip addr"
    NetworkStatTool="ss -an"
    HostnameGetTool=$(ip addr show | grep -v '127*' | grep -Po 'inet \K[\d.]+' | sed 's/[[:blank:]]\+/\n/g')
else
    NetworkInterfaceTool="ifconfig -a"
    NetworkStatTool="netstat -an"
    HostnameGetTool=$(ifconfig | grep 'inet ' | grep -v '127*' | awk -F'[: ]+' '{ print $4 }' | sed 's/[[:blank:]]\+/\n/g')
fi

echo ' '
echo '   sadiag.sh - Shell Antivirus DIAGnostic script'
echo '   v.0.066 - 2007-FEB-20'
echo ' '
echo '   Please wait while your data is gathered...'
echo ' '

echo ' ' > sadiag.txt 2>&1
echo 'sadiag.sh - Shell Antivirus DIAGnostic script' >>sadiag.txt 2>&1
echo 'v.0.066 - 2007-FEB-20' >>sadiag.txt 2>&1
echo '-----------------------' >>sadiag.txt 2>&1
echo "Hostname: `uname -n 2>&1`" >>sadiag.txt 2>&1
echo "Date Run: `date 2>&1`" >>sadiag.txt 2>&1
echo "Username: `whoami 2>&1`" >>sadiag.txt 2>&1
echo "Uptime : `uptime 2>&1`" >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1

 
echo "   `date +%k:%M:%S` Detecting operating system..."
echo 'Raw Kernel Information: ' >>sadiag.txt 2>&1
echo '   ' `uname -a` >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Interpreted Operating System Information' >>sadiag.txt 2>&1
if [ "`uname -s`" = "Darwin" ] ; then echo "OS: `sw_vers | sed -e 1q | cut -d ':' -f2`" >>sadiag.txt  2>&1
elif [ "`uname -s`" = "SunOS" ] ; then echo "OS: Solaris" >>sadiag.txt  2>&1
else echo "OS: `uname -s`" >>sadiag.txt  2>&1 #Linux and generic
fi
if [ "`uname -s`" = "Darwin" ] ; then echo "Distro: `sw_vers | sed -e '1d; 2q' | cut -d ':' -f2`" >>sadiag.txt  2>&1
elif [ "`uname -s`" = "SunOS" ] ; then echo "Distro: `uname -r`" >>sadiag.txt 2>&1
else if [ -a /etc/redhat-release ] ; then # RH symlink
   echo "Distro: `cat /etc/redhat-release``uname -r`" | grep '.' >>sadiag.txt  2>&1 
   elif [ -f /etc/SuSE-release ] ; then
   echo "Distro: `cat /etc/SuSE-release | tr "\n" ' ' | sed -e 's/VERSION.*//'``cat /etc/SuSE-release | tr "\n" ' ' | sed -e 's/.*=\s//'`" | grep '.' >>sadiag.txt  2>&1
   else echo "Distro: Unsupported Distribution, Unsupported revision"
   fi
fi
if [ "`uname -s`" = "SunOS" ] ; then echo "Kernel: `uname -v`" >>sadiag.txt 2>&1
else echo "Kernel: `uname -r`" >>sadiag.txt 2>&1
fi
if [ "`uname -s`" = "SunOS" ] ; then echo "Architecture: `uname -p`" >>sadiag.txt 2>&1
else echo "Architecture: `uname -m`" >>sadiag.txt 2>&1
fi
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Detecting system resources..."
echo 'Detected System Resources' >>sadiag.txt 2>&1
echo '--------------------------' >>sadiag.txt 2>&1
echo 'Detected CPU: ' >>sadiag.txt 2>&1
   if [ "`uname -s`" = "SunOS" ] ; then 
      isainfo -vk >> sadiag.txt 2>/dev/null
      dmesg | grep 'root nexus' 2>&1 | cut -d '=' -f2 >>sadiag.txt 2>/dev/null
   elif [ "`uname -s`" = "Darwin" ] ; then   
      /usr/bin/hostinfo 2>/dev/null | grep processor >>sadiag.txt 2>/dev/null
   else cat /proc/cpuinfo >>sadiag.txt 2>/dev/null
   fi
echo '' >>sadiag.txt 2>&1
echo 'Detected memory:'  >>sadiag.txt 2>&1
   if [ "`uname -s`" = "SunOS" ] ; then  prtconf -pv 2>/dev/null | grep Mem >>sadiag.txt 2>/dev/null
   elif [ "`uname -s`" = "Darwin" ] ; then /usr/bin/hostinfo 2>/dev/null | grep emory >>sadiag.txt 2>/dev/null
   else free  >>sadiag.txt 2>/dev/null
   fi
   vmstat >>sadiag.txt 2>/dev/null
echo '' >>sadiag.txt 2>&1
echo 'Available free disk space on local mounts:' >>sadiag.txt 2>&1
   df -k >>sadiag.txt 2>&1
echo '' >>sadiag.txt 2>&1
echo 'Filetypes of each local drive:' >>sadiag.txt 2>&1
   if [ "`uname -s`" = "Darwin" ] ; then pdisk L >>sadiag.txt 2>/dev/null ; fi
   mount >>sadiag.txt 2>/dev/null
echo '' >>sadiag.txt 2>&1
echo 'Location of System temp folder:' >>sadiag.txt 2>&1
   mount 2>/dev/null | grep "/tmp" >>sadiag.txt 2>&1
   mount 2>/dev/null | grep "/Temp" >>sadiag.txt 2>&1
   mount 2>/dev/null | grep "/ " >>sadiag.txt 2>&1
echo '' >>sadiag.txt 2>&1
echo 'Quota restrictions (if any):' >>sadiag.txt 2>&1
   echo "umask value"$'\t'$'\t'$'\t' " `umask`" >>sadiag.txt 2>/dev/null
   quota -ls >>sadiag.txt 2>/dev/null
   ulimit -a >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Detecting network resources..."
echo 'Detected Network Resources' >>sadiag.txt 2>&1
echo '------------------------------' >>sadiag.txt 2>&1
echo 'Network interfaces:' >>sadiag.txt 2>&1
    $NetworkInterfaceTool >>sadiag.txt 2>&1    
echo 'ipv4 stack hardening parameters:' >>sadiag.txt 2>&1
if [ "`uname -s`" = "SunOS" ] ; then 
   echo 'tcp_time_wait_interval =' `ndd -get /dev/tcp tcp_time_wait_interval 2>&1` >>sadiag.txt 2>&1
   echo 'tcp_smallest_anon_port =' `ndd -get /dev/tcp tcp_smallest_anon_port 2>&1` >>sadiag.txt 2>&1
   echo 'tcp_largest_anon_port =' `ndd -get /dev/tcp tcp_largest_anon_port 2>&1` >>sadiag.txt 2>&1
elif [ "`uname -s`" = "Darwin" ] ; then
   sysctl kern.ipc.maxsockbuf >>sadiag.txt 2>&1
   sysctl net.inet.tcp.sendspace >>sadiag.txt 2>&1
   sysctl net.inet.tcp.recvspace >>sadiag.txt 2>&1
elif [ "`uname -s`" = "Linux" ] ; then
   sysctl net.ipv4.tcp_max_syn_backlog net.ipv4.tcp_syncookies net.ipv4.ip_local_port_range net.core.rmem_max net.core.wmem_max net.ipv4.tcp_rmem net.ipv4.tcp_wmem >>sadiag.txt 2>&1
   if [ "`uname -r | cut -d '.' -f1,2`" = "2.4" ] ; then sysctl net.ipv4.route.flush >>sadiag.txt 2>&1
   elif [ "`uname -r | cut -d '.' -f1,2`" = "2.6" ] ; then
   sysctl net.ipv4.tcp_no_metrics net.core.netdev_max_backlog net.ipv4.tcp_congestion_control >>sadiag.txt 2>&1
   fi
   ethtool -k eth0 >>sadiag.txt 2>&1
fi
echo ' ' >>sadiag.txt 2>&1
echo 'Contents of /etc/resolv.conf:' >>sadiag.txt 2>&1
cat /etc/resolv.conf >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1

if [ "`echo $1`" = "-j" ] ; then
echo 'DNS Record test:' >>sadiag.txt 2>&1
if [ "`dig -v 2>&1 | cut -d ' ' -f1`" = "DiG" ] ; then 
   for DIGSERVER in `cat /etc/resolv.conf | grep nameserver | cut -d ' ' -f2` ; do {
      echo "Records for the local host found within nameserver: $DIGSERVER" >>sadiag.txt
      for DACHECK in `uname -n` ; do {
         echo "Checking $DIGSERVER for an A record which matches $DACHECK" >>sadiag.txt
         dig @$DIGSERVER $DACHECK A >>sadiag.txt 2>&1
         echo ' ' >>sadiag.txt
      } ; done      
      for DPTRCHECK in ${HostnameGetTool} ; do {
         echo "Checking $DIGSERVER for a PTR record which matches $DPTRCHECK" >>sadiag.txt 2>&1
         dig @$DIGSERVER $DPTRCHECK PTR >> sadiag.txt 2>&1
         echo ' ' >>sadiag.txt
      } ; done
   }; done     
else
echo 'Unable to use either dig or nslookup to examine records for localhost on nameserver.' >>sadiag.txt 2>&1
fi
else
echo 'sadiag did not receive the -j command line parameter.' >>sadiag.txt 2>&1
echo 'No attempts to connect to DNS servers are authorized.' >>sadiag.txt 2>&1
echo 'Proceeding to detecting software environment...' >>sadiag.txt 2>&1
fi
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Detecting software environment..."
echo 'Detected Software Environment' >>sadiag.txt 2>&1
echo '------------------------------' >>sadiag.txt 2>&1
echo 'Detected operating system libraries:' >>sadiag.txt 2>&1
   if [ "`uname -s`" = "Linux" ] 
   then rpm -q compat-libstdc++ 2>/dev/null >>sadiag.txt 2>/dev/null ; fi
   if [ "`uname -r`" = "5.9" ]
   then showrev -p 2>/dev/null | grep 115697 >>sadiag.txt 2>/dev/null; fi
   if [ "`uname -r`" = "5.8" ]
   then showrev -p 2>/dev/null | grep 112438 >>sadiag.txt 2>/dev/null; fi
   if [ "`uname -s`" = "Darwin" ]
   then cat /private/var/log/install.log 2>/dev/null | grep 'Security Update 2006-004' >>sadiag.txt 2>&1 ; fi
echo ' ' >>sadiag.txt 2>&1
echo 'First three lines of java -version response:' >>sadiag.txt 2>&1
if [ "`uname -s`" = "Darwin" ] ; then java -showversion 2>&1 | head -n 3 >>sadiag.txt 2>/dev/null
else java -version 2>&1 | head -n 3 >>sadiag.txt 2>/dev/null ; fi
echo ' ' >>sadiag.txt 2>&1
echo 'Java found within the path (if any):' >>sadiag.txt 2>&1
   ls -l `which java 2>/dev/null` /dev/null | grep -v /dev/null >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Checking for a mail server listening on port 25... ' >>sadiag.txt 2>&1
echo '   Listening on TCP/25: '"`$NetworkStatTool | grep ':25'`" >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
if [ -f /opt/lotus/bin/server ] ; then
   echo 'Checking which java Domino (if present) uses...' >>sadiag.txt 2>&1
   ls -l /opt/lotus/notes/latest/*/java >>sadiag.txt 2>/dev/null
   echo ' ' >>sadiag.txt 2>&1
   echo 'Response from Domino server in default location:' >>sadiag.txt 2>&1
   /opt/lotus/bin/server -c "SHOW SERVER STAT" >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1 ; fi   
echo 'Detected version of sendmail via -bt parameter:' >>sadiag.txt 2>&1
   echo "`/usr/lib/sendmail -bt -d0 < /dev/null 2>&1`" >>sadiag.txt 2>&1
echo 'Note: if the above line includes "unsupported: -bt", SMTP5 or an older version of postfix is present.' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Detected packaging programs:' >>sadiag.txt 2>&1
   tar --version >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Detecting Symantec shared resources..."
echo 'Symantec Shared Resources' >>sadiag.txt 2>&1
echo '------------------------------' >>sadiag.txt 2>&1
echo 'Detected groups related to Symantec security software:' >>sadiag.txt 2>&1
if [ -f /etc/group ] ; then
   cat /etc/group 2>/dev/null | grep 'avdefs' >>sadiag.txt 2>&1
   cat /etc/group 2>/dev/null | grep 'bmi' >>sadiag.txt 2>&1
   cat /etc/group 2>/dev/null | grep 'mysql' >>sadiag.txt 2>&1
   cat /etc/group 2>/dev/null | grep 'postfix' >>sadiag.txt 2>&1
   cat /etc/group 2>/dev/null | grep 'postdrop' >>sadiag.txt 2>&1
   cat /etc/group 2>/dev/null | grep 'tomcat' >>sadiag.txt 2>&1
elif [ "`uname -s`" = "Darwin" ] ; then 
   echo "`nidump group . | grep mysql 2>/dev/null`" >>sadiag.txt 2>&1
   echo "`nidump group . | grep postfix 2>/dev/null`" >>sadiag.txt 2>&1
   echo "`nidump group . | grep postdrop 2>/dev/null`" >>sadiag.txt 2>&1
fi
echo ' ' >>sadiag.txt 2>&1
echo 'Detected users related to Symantec security software:' >>sadiag.txt 2>&1
if [ -f /etc/group ] ; then
   cat /etc/passwd 2>/dev/null | grep mailwall >>sadiag.txt 2>&1
   cat /etc/passwd 2>/dev/null | grep mysql >>sadiag.txt 2>&1
   cat /etc/passwd 2>/dev/null | grep postfix >>sadiag.txt 2>&1
   cat /etc/passwd 2>/dev/null | grep amavis >>sadiag.txt 2>&1
   cat /etc/passwd 2>/dev/null | grep clamav >>sadiag.txt 2>&1
   cat /etc/passwd 2>/dev/null | grep mailman >>sadiag.txt 2>&1
elif [ "`uname -s`" = "Darwin" ] ; then 
   echo "`nidump passwd . | grep mysql 2>&1`" >>sadiag.txt 2>&1
   echo "`nidump passwd . | grep postfix 2>&1`" >>sadiag.txt 2>&1
   echo "`nidump passwd . | grep amavis 2>&1`" >>sadiag.txt 2>&1
   echo "`nidump passwd . | grep clamav 2>&1`" >>sadiag.txt 2>&1
   echo "`nidump passwd . | grep mailman 2>&1`" >>sadiag.txt 2>&1
fi   
echo ' ' >>sadiag.txt 2>&1
echo 'Searching for Symantec Licenses:' >>sadiag.txt 2>&1
   ls /opt/Symantec/Licenses >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'VirusDefs integrity test:' >>sadiag.txt 2>&1
for VDEFROOT in `ls -d /opt/Symantec/virusdefs /opt/SYMCScan/bin/definitions/AntiVirus /opt/Symantec/SMSSMTP/scanner/rules  /opt/symantec/sbas/Scanner 2>/dev/null` ; do {
   echo "${VDEFROOT}" >>sadiag.txt 2>&1
   for VDEFDIRS in `ls ${VDEFROOT} | grep 200 | tr "\n" ' '` `ls ${VDEFROOT} | grep VirusDefs` `ls ${VDEFROOT} 2>/dev/null | grep avsym | tr "\n" ' '` `ls ${VDEFROOT} | grep binhub | tr "\n" ' '`; do {
      echo ' ' >>sadiag.txt 2>&1
      echo "${VDEFROOT}/${VDEFDIRS}:" >>sadiag.txt 2>/dev/null
      echo "Filename"$'\t'"SHA-1 Hash"$'\t\t\t\t\t'"hash recorded in v.grd" >>sadiag.txt 2>&1
      for VDEFFILE in `ls -1 ${VDEFROOT}/${VDEFDIRS}/ | tr "\n" ' '`; do {
         if [ "`uname -s`" = "SunOS" ] ; then
	 echo "${VDEFFILE}"$'\t'"`digest -a sha1 ${VDEFROOT}/${VDEFDIRS}/${VDEFFILE}`"$'\t'"`digest -a sha1 ${VDEFROOT}/${VDEFDIRS}/${VDEFFILE} | xargs -iHASH grep HASH ${VDEFROOT}/${VDEFDIRS}/v.grd | cut -d '=' -f2`" >>sadiag.txt 2>&1
	 else
	 echo "${VDEFFILE}"$'\t'"`openssl sha1 ${VDEFROOT}/${VDEFDIRS}/${VDEFFILE} | cut -d '=' -f2`"$'\t'"`openssl sha1 ${VDEFROOT}/${VDEFDIRS}/${VDEFFILE} | cut -d '=' -f2 | xargs -iHASH grep -o HASH ${VDEFROOT}/${VDEFDIRS}/v.grd`" >>sadiag.txt 2>&1
	 fi
         echo ' ' >>/dev/null
      } ;
      done
      echo ' ' >>sadiag.txt 2>&1
   };
   done   
};
done
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Performing LiveUpdate diagnostics..."
echo 'LiveUpdate Diagnostics' >>sadiag.txt 2>&1
echo '--------------------------' >>sadiag.txt 2>&1

echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1

echo 'Contents of LiveUpdate application folder:' >>sadiag.txt 2>&1
ls ${product_root}/LiveUpdate >>sadiag.txt 2>&1 ;
echo ' ' >>sadiag.txt 2>&1

echo 'Contents of virusdefs/incoming:' >>sadiag.txt 2>&1
ls ${product_root}/virusdefs/incoming ${product_root}/LiveUpdate/LiveUpdateDownloads >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1

echo 'Contents of virusdefs:' >>sadiag.txt 2>&1
echo ' '`ls ${product_root}/virusdefs 2>&1` >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1

echo 'Contents of /etc/Symantec.conf:' >>sadiag.txt
   cat /etc/Symantec.conf >>sadiag.txt 2>&1

echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Detecting Symantec security products..."
echo 'Detected Security Products' >>sadiag.txt 2>&1
echo '--------------------------' >>sadiag.txt 2>&1
if [ "`uname -s`" = "Darwin" ] ; then
   if [ -d /var/mysql/smac ] ; then 
      echo "SMac Server appears to be installed. /var/mysql/smac is present."  >>sadiag.txt 2>&1
   fi
elif [ "`uname -s`" = "Linux" ] ; then
echo 'SAV modules detected:' >>sadiag.txt 2>&1
echo '   sav:' `rpm -q sav 2>/dev/null` >>sadiag.txt 2>&1
   rpm -V sav 2>&1 | grep -v 'command not found' | grep -v virusdefs >>sadiag.txt 2>/dev/null
echo '   savap:' `rpm -q savap 2>/dev/null` >>sadiag.txt 2>&1
   rpm -V savap 2>&1  | grep -v 'command not found' >>sadiag.txt 2>/dev/null
echo '   savui:' `rpm -q savui 2>/dev/null` >>sadiag.txt 2>&1
   rpm -V savui 2>&1  | grep -v 'command not found' >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'SMSSMTP5 modules detected:' >>sadiag.txt 2>&1
echo '   sms-smtp:' `rpm -q sms-smtp 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-base:' `rpm -q sms-smtp-base 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-bcc:' `rpm -q sms-smtp-bcc 2>/dev/null`>>sadiag.txt 2>&1
echo '   sms-smtp-connector:' `rpm -q sms-smtp-connector 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-mta:' `rpm -q sms-smtp-mta 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-modules:' `rpm -q sms-smtp-modules 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-mysql-init:' `rpm -q sms-smtp-mysql-init 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-sync-service:' `rpm -q sms-smtp-sync-service 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-tomcat:' `rpm -q sms-smtp-tomcat 2>/dev/null` >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'SMSSMTP4 modules detected:' >>sadiag.txt 2>&1
echo '   SYMCsmtp: ' `rpm -q SYMCsmtp 2>/dev/null` >>sadiag.txt 2>&1
   cat /var/log/SMSSMTP-install.log 2>/dev/null | grep 'Installation of <SYMCsmtp>' >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'Scan Engine modules detected:' >>sadiag.txt 2>&1
echo '   SYMCScan: ' `rpm -q SYMCScan 2>/dev/null` >>sadiag.txt 2>&1
   cat /var/log/SYMCScan-install.log 2>/dev/null | grep '<SYMCScan>' >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'SWS modules detected:' >>sadiag.txt 2>&1
echo '   SYMCsws: ' `rpm -q SYMCsws 2>/dev/null` >>sadiag.txt 2>&1
   cat /var/log/SWS-install.log 2>/dev/null | grep '<SYMCsws>' >>sadiag.txt 2>/dev/null
elif [ "`uname -s`" = "SunOS" ] ; then
echo 'SMSSMTP5 modules detected:' >>sadiag.txt 2>&1
echo '   sms-smtp:' `pkginfo sms-smtp 2>&1` >>sadiag.txt 2>&1
echo '   sms-smtp-base:' `pkginfo sms-smtp-base 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-bcc:' `pkginfo sms-smtp-bcc 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-connector:' `pkginfo sms-smtp-connector 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-mta:' `pkginfo sms-smtp-mta 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-modules:' `pkginfo sms-smtp-modules 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-mysql-init:' `pkginfo sms-smtp-mysql-init 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-sync-service:' `pkginfo sms-smtp-sync-service 2>/dev/null` >>sadiag.txt 2>&1
echo '   sms-smtp-tomcat:' `pkginfo sms-smtp-tomcat 2>/dev/null` >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'SMSSMTP4 modules detected:' >>sadiag.txt 2>&1
echo '   SYMCsmtp: ' `pkginfo SYMCsmtp 2>/dev/null` >>sadiag.txt 2>&1
   cat /var/log/SMSSMTP-install.log 2>/dev/null | grep '<SYMCsmtp>' >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'Scan Engine modules detected:' >>sadiag.txt 2>&1
echo '   SYMCScan: ' `pkginfo SYMCScan 2>/dev/null` >>sadiag.txt 2>&1
   cat /var/log/SYMCScan-install.log 2>/dev/null | grep '<SYMCScan>' >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'SWS modules detected:' >>sadiag.txt 2>&1
echo '   SYMCsws: ' `pkginfo SYMCsws 2>/dev/null` >>sadiag.txt 2>&1
   cat /var/log/SWS-install.log 2>/dev/null | grep '<SYMCsws>' >>sadiag.txt 2>/dev/null
fi
echo ' ' >>sadiag.txt 2>&1
if [ "`uname -s`" = "Darwin" ] ; then echo ' ' >/dev/null ; else 
   if [ -f /opt/symantec/sbas/ControlCenter/Brightmail_Control_Center_InstallLog.log ] ; then
      echo 'SBAS6 Control Center install results:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/ControlCenter/Brightmail_Control_Center_InstallLog.log | grep 'Installation: ' >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
   fi
   if [ -f /opt/symantec/sbas/Scanner/Brightmail_Scanner_InstallLog.log ] ; then 
      echo 'SBAS6 Scanner install results:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/Scanner/Brightmail_Scanner_InstallLog.log | grep 'Installation: ' >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
   fi
fi
echo 'Symantec security related processes detected via ps:' >>sadiag.txt 2>&1
if [ "`uname -s`" = "SunOS" ] ; then 
   echo '  PID TTY      STAT   TIME COMMAND' >>sadiag.txt 2>&1
      ps -ef | grep [Ss]ym | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep [Bb]cc | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep conduit | grep -v grep  >>sadiag.txt 2>&1
      ps -ef | grep ldapsync | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep [Jj]ava | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep [Mm]ysqld | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep [Mm]ail | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep [Ss]av | grep -v grep >> sadiag.txt 2>&1      
      ps -ef | grep ntask | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep server | grep -v kdeinit | grep -v grep >>sadiag.txt 2>&1
      ps -ef | grep exim | grep -v grep >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
else # MacOS or Linux
   echo '  PID TTY      STAT   TIME COMMAND' >>sadiag.txt 2>&1
      ps ax | grep [Ss]ym | grep -v grep >>sadiag.txt 2>&1
      ps ax | grep [Bb]cc | grep -v grep >>sadiag.txt 2>&1
      ps ax | grep conduit | grep -v grep  >>sadiag.txt 2>&1
      ps ax | grep ldapsync | grep -v grep  >>sadiag.txt 2>&1
      ps ax | grep [Jj]ava | grep -v grep  >>sadiag.txt 2>&1
      ps ax | grep [Mm]ysqld | grep -v grep >>sadiag.txt 2>&1
      ps ax | grep [Mm]ail | grep -v grep >>sadiag.txt 2>&1
      ps ax | grep [Ss]av | grep -v grep >>sadiag.txt 2>&1
      ps ax | grep ntask | grep -v grep >>sadiag.txt 2>&1   
      ps ax | grep server | grep -v kdeinit | grep -v grep >>sadiag.txt 2>&1
      ps ax | grep exim | grep -v grep >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
fi
   if [ "`uname -s`" = "Darwin" ] ; then
      echo 'SAV Status Report' >>sadiag.txt 2>&1
      echo '   Version    :'" `strings /Applications/Symantec*/Norton*app/Contents/Info.plist 2>/dev/null | grep CFBundleShortVersionString 2>/dev/null``/Library/Application\ Support/Symantec/SMac/CmdExec/Tools/SymPkgVersion 2>/dev/null``/Library/Application\ Support/Symantec/SMac/CmdExec/Tools/SymPkgVersion 2>/dev/null`" >>sadiag.txt 2>/dev/null
   elif [ "`uname -s`" = "Linux" ] ; then 
      echo 'SAV Status Report' >>sadiag.txt 2>&1
      echo '   Version    :'" `/opt/Symantec/symantec_antivirus/sav info -p 2>/dev/null`" >>sadiag.txt 2>/dev/null
      echo '   Engine     :'" `/opt/Symantec/symantec_antivirus/sav info -e 2>/dev/null`" >>sadiag.txt 2>&1
      echo '   Virus Defs :'" `/opt/Symantec/symantec_antivirus/sav info -d 2>/dev/null`" >>sadiag.txt 2>&1
      echo '   Autoprotect:'" `/opt/Symantec/symantec_antivirus/sav info -a 2>/dev/null`" >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      echo 'SAV Scan Status:' >>sadiag.txt 2>&1
         /opt/Symantec/symantec_antivirus/sav info -s >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1
      echo 'SAV LU Schedule:' >>sadiag.txt 2>&1
         /opt/Symantec/symantec_antivirus/sav liveupdate -v >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1
      echo 'SAV Quarantine Items:' >>sadiag.txt 2>&1
         /opt/Symantec/symantec_antivirus/sav quarantine -l >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1
      echo 'SAV Scan Exclusions:' >>sadiag.txt 2>&1
         /opt/Symantec/symantec_antivirus/symcfg -r list 2>&1 | grep Exception >>sadiag.txt 2>/dev/null
         /opt/Symantec/symantec_antivirus/symcfg -r list 2>&1 | grep NoScanDir >>sadiag.txt 2>/dev/null
   fi
echo ' ' >>sadiag.txt 2>&1
if [ "`uname -s`" = "Darwin" ] ; then echo ' ' >>/dev/null ; else
   if [ "`ls -d /opt/?ymantec/*/?canner /opt/SMSSMTP/csapi/BMI 2>/dev/null`" = "" ] ; then echo ' ' >/dev/null ; else
   echo 'Scanner Status for SMTP5/SBAS6/SMTP4+PAS' >>sadiag.txt 2>&1
   echo '   Scanner conduit bmiversion: '"`strings /opt/?ymantec/*/?canner/bin/conduit /opt/SMSSMTP/csapi/BMI/bin/conduit 2>/dev/null | grep bmiversion | grep -v '%'`" >>sadiag.txt 2>&1
   echo '   Scanner patchlevel by date: '"`ls -cl --time-style=+%Y-%b-%d /opt/?ymantec/*/*/bin/filter-hub /opt/SMSSMTP/csapi/BMI/bin/bmserver 2>/dev/null | cut -d ' ' -f7`" >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
   fi
   if [ "`ls -d /opt/Symantec/SMSSMTP/tomcat /opt/symantec/sbas/ControlCenter/Tomcat 2>/dev/null`" = "" ] ; then echo ' ' >/dev/null ; else
   echo 'Control Center Status for SBAS6/SMTP5' >>sadiag.txt 2>&1
   echo "   Control Center Version: `grep 'label.about.version'  /opt/Symantec/SMSSMTP/tomcat/webapps/brightmail/WEB-INF/classes/brightmailLabelBundle.properties 2>/dev/null | cut -d ':' -f2 | grep -v '%'` `grep 'label.about.version'  /opt/symantec/sbas/ControlCenter/Tomcat/jakarta-tomcat-4.1.27/webapps/brightmail/WEB-INF/classes/brightmailLabelBundle.properties 2>/dev/null | cut -d "=" -f2 | grep -v '%'`" >>sadiag.txt 2>&1
   echo '   Listening on TCP/41025: '"`$NetworkStatTool | grep ':41025'`" >>sadiag.txt 2>&1
   echo '   Listening on TCP/41080: '"`$NetworkStatTool | grep ':41080'`" >>sadiag.txt 2>&1
   echo '   Listening on TCP/41443: '"`$NetworkStatTool | grep ':41443'`" >>sadiag.txt 2>&1
   #echo '   Listening on TCP/25: '"`$NetworkStatTool | grep ':25'`" >>sadiag.txt 2>&1
   fi
fi
for mysqldirs in `ls -d /opt/Symantec/SMSSMTP/mysql /opt/symantec/sbas/ControlCenter/MySQL/mysql-pro-4.0.16-* /var/mysql 2>&1 | grep -v 'No such' | grep -v '.tar'`; do {
   echo ' ' >>sadiag.txt 2>&1
   echo "Checking mysql structure ${mysqldirs}" >>sadiag.txt 2>&1
#   echo "Total aggregate size of mysql indexes: "$((`ls -lR $mysqldirs 2>/dev/null | grep MYI | cut -d ' ' -f6 | grep [0-9] | tr "\n" '+'`0)) >>sadiag.txt
   if [ -d ${mysqldirs}/data ] ; then {
   echo "Index limit set in my.cnf: `cat ${mysqldirs}data/my.cnf 2>&1 | grep key_buffer | grep '=' | head -n 1`" >>sadiag.txt
   echo "MySQLdbase="$'\t'"frm"$'\t'"MYI"$'\t'"MYD"$'\t'"CAP" >>sadiag.txt 2>&1
   for mysqltables in `ls -ld ${mysqldirs}/data/* | grep drw | cut -d ' ' -f11`; do 
      echo " `find ${mysqltables} -type d -printf \"%f\"`"$'\t'"`ls ${mysqltables}/*frm 2>/dev/null | wc -l`"$'\t'"`ls ${mysqltables}/*MYI 2>/dev/null | wc -l`"$'\t'"`ls ${mysqltables}/*MYD 2>/dev/null | wc -l`"$'\t'"`ls -l  ${mysqltables} | cut -d ' ' -f6 | grep [1-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9] | wc -l`" >>sadiag.txt 2>&1 
   done  # end for mysqltables
   }
   else {
   echo "Index limit set in my.cnf: `cat ${mysqldirs}/my.cnf 2>&1 | grep key_buffer | grep '=' | head -n 1`" >>sadiag.txt
   echo "MySQLdbase="$'\t'"frm"$'\t'"MYI"$'\t'"MYD"$'\t'"CAP" >>sadiag.txt 2>&1
   for mysqltables in `ls -ld ${mysqldirs}/* | grep drw | cut -d ' ' -f11`; do 
      echo " `find ${mysqltables} -type d -printf \"%f\"`"$'\t'"`ls ${mysqltables}/*frm 2>/dev/null | wc -l`"$'\t'"`ls ${mysqltables}/*MYI 2>/dev/null | wc -l`"$'\t'"`ls ${mysqltables}/*MYD 2>/dev/null | wc -l`"$'\t'"`ls ${mysqltables} | cut -d ' ' -f6 | grep [0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9] | wc -l`" >>sadiag.txt 2>&1 
   done  # end for mysqltables
   }
   fi
#   echo '   Symantec MySQL component detected. For a mysqlcheck of this structure,'
#   echo '   please enter your MySQL password. Otherwise, press <ENTER> to continue.'
#   echo '   Results of mysqlcheck on the brightmail table:' >>sadiag.txt 2>&1
#   $mysqldirs/bin/mysqlcheck -h127.0.0.1 -ubrightmailuser -p -r >>sadiag.txt 2>&1
   } ; done #end mysqldirs
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1


echo "   `date +%k:%M:%S` Gathering bulk data..."
echo 'Bulk Data Gathering' >>sadiag.txt
echo '--------------------------' >>sadiag.txt
echo 'OS specific system profile information (if available):' >>sadiag.txt 2>&1
if [ "`uname -s`" = "Darwin" ] ; then echo "`system_profiler 2>/dev/null`" >>sadiag.txt 2>&1
elif [ "`uname -s`" = "SunOS" ] ; then
   showrev -a >>sadiag.txt 2>/dev/null
   prtconf >>sadiag.txt 2>/dev/null
   cat /etc/system >>sadiag 2>/dev/null
fi
echo ' ' >>sadiag.txt 2>&1
#echo 'Searching for Java links and executables on all local mounts:' >>sadiag.txt 2>&1
#   find / -xdev -name java >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'List of core files stored on local mounts (if any):' >>sadiag.txt
if [ "`uname -s`" = "Darwin" ] ; then
ls /cores/core.* >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Recursive directory listing of system logs:' >>sadiag.txt 2>&1
   ls -lR /*/[Ll]og? /*/*/[Ll]og? >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Recursive directory listing of Symantec related directories:' >>sadiag.txt 2>&1
   ls -lR /*/[Ss]ymantec*  /*/*/[Ss]ymantec* /Applications/[Nn]orton* >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'Spools present on the system:' >>sadiag.txt 2>&1
   ls -l /private/var/spool >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 
echo 'Contents of SMac Server basic config file:' >>sadiag.txt 2>&1
   cat "/Library/Application\ Support/Symantec/config" >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Current full configuration of SAV:' >>sadiag.txt 2>&1
   cat /Library/Preferences/com.symantec.SMacClient.plist >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt
echo 'Last 1000 lines of /private/var/log/install.log:' >>sadiag.txt 2>&1
   tail -n 1000 /private/var/log/install.log  >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt
echo 'Contents of /private/etc/httpd/sites/symantec.conf:' >>sadiag.txt 2>&1
   cat /private/etc/httpd/sites/symantec.conf >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt
echo 'Contents of /private/etc/Bastille/config:' >>sadiag.txt 2>&1
   cat /private/etc/Bastille/config >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt   
else
#find / -xdev -name core -type f >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt   
echo 'Recursive directory listing of system logs:' >>sadiag.txt 2>&1
   ls -lR /*/[Ll]og? >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
echo 'Recursive directory listing of Symantec related directories:' >>sadiag.txt 2>&1
   ls -lR /*/[Ss]ymantec*  /*/*/[Ss]ymantec* /usr/local/[Bb]rightmail /var/opt/SMSSMTP /opt/SYMCScan /opt/SYMCsws /var/opt/SYMCsws >>sadiag.txt 2>/dev/null
echo ' ' >>sadiag.txt 2>&1
echo 'Spools present on the system:' >>sadiag.txt 2>&1
   ls -l /var/spool >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 
   if [ -f /root/Bastille/config ] ; then
      echo 'Contents of /private/etc/Bastille/config:' >>sadiag.txt 2>&1
         cat /root/Bastille/config >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt
   fi   
   if [ -f /var/log/SYMCScan-install.log ] ; then
      if [ "`cat /var/log/SYMCScan-install.log 2>&1 | grep '<SYMCScan>' 2>/dev/null`" = "Installation of <SYMCScan> Completed" ] ; then echo ' ' >/dev/null
      else 
      echo ' Installation log for Scan Engine:' >>sadiag.txt 2>&1
      cat /var/log/SYMCScan-install.log >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      fi
   fi
   if [ -f /var/log/SWS-install.log ] ; then
      if [ "`cat /var/log/SYMCScan-install.log 2>&1 | grep '<SYMCsws>' 2>/dev/null`" = "Installation of <SYMCsws> Completed" ] ; then echo ' ' >/dev/null
      else 
      echo ' Installation log for SWS3.x:' >>sadiag.txt 2>&1
      cat /var/log/SWS-install.log >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      fi
   fi
   if [ -f /var/log/SMSSMTP-install.log ] ; then
      if [ "`cat /var/log/SMSSMTP-install.log 2>&1 | grep '<SYMCsmtp>' 2>/dev/null`" = "Installation of <SYMCsmtp> Completed" ] ; then 
      echo 'Basic config for SMTP4.x:' >>sadiag.txt 2>&1
      cat /opt/SMSSMTP/local/local-config /opt/SMSSMTP/local/SMSSMTP.cfg >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      if [ -f /opt/SMSSMTP/csapi/BMI/registerbeik.slf ] ; then 
         echo 'Premium Antispam was registered at some point.' >>sadiag.txt 2>&1
         echo ' ' >>sadiag.txt 2>&1
      fi
      echo 'bmiconfig, allowedblockedlist for SMTP4 w/SPA:' >>sadiag.txt 2>&1
      cat /opt/SMSSMTP/csapi/BMI/config/bmiconfig.xml /opt/SMSSMTP/csapi/BMI/etc/allowedblockedlist.txt >>sadiag.txt 2>/dev/null
      else
      echo ' Installation log for SMSSMTP4.x:' >>sadiag.txt 2>&1
      cat /var/log/SMSSMTP-install.log >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      fi
   fi
   if [ -f /opt/Symantec/SMSSMTP/install_log.txt ] ; then    
      echo ' Installation log for SMSSMTP5.x:' >>sadiag.txt 2>&1
      cat /opt/Symantec/SMSSMTP/install_log.txt >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      echo 'Detailed installation logs for SMSSMTP5.x modules:' >>sadiag.txt 2>&1
      cat /root/sms-smtp*-install.log >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
      echo 'Contents of server.xml for local SMTP5 ControlCenter:' >>sadiag.txt 2>&1
      cat /opt/Symantec/SMSSMTP/tomcat/conf/server.xml >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1
      echo 'Contents of bmiconfig.xml for local Scanner:' >>sadiag.txt 2>&1
      cat /opt/Symantec/SMSSMTP/scanner/etc/bmiconfig.xml >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1   
      echo 'Contents of agentconfig.xml for local Scanner:' >>sadiag.txt 2>&1
      cat /opt/Symantec/SMSSMTP/scanner/etc/agentconfig.xml >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1
      echo 'Contents of mtaconfig.xml for local Scanner:' >>sadiag.txt 2>&1
      cat /opt/Symantec/SMSSMTP/mta/etc/mtaconfig.xml >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1   
      echo 'Contents of sieve_script.txt for local Scanner:' >>sadiag.txt 2>&1
      cat /opt/Symantec/SMSSMTP/scanner/etc/sieve_script.txt >>sadiag.txt 2>/dev/null
      echo ' ' >>sadiag.txt 2>&1
   fi
   if [ -f /opt/symantec/sbas/ControlCenter/Brightmail_Control_Center_InstallLog.log ] ; then 
   if [ "`cat /opt/symantec/sbas/ControlCenter/Brightmail_Control_Center_InstallLog.log 2>&1 | grep '1100 SUCCESSES' 2>&1`" = "1100 SUCCESSES" ] ; then 
      echo 'Contents of server.xml for local SBAS6 ControlCenter:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/ControlCenter/Tomcat/jakarta-tomcat-4.1.27/conf/server.xml >>sadiag.txt 2>/dev/null
   else
      echo ' Installation log(s) for SBAS6CC:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/ControlCenter/Brightmail_Control_Center_InstallLog.log >>sadiag.txt 2>&1
   fi; echo ' ' >>sadiag.txt 2>&1 ; fi
   if [ -f /opt/symantec/sbas/Scanner/Brightmail_Scanner_InstallLog.log ] ; then 
   if [ "`cat /opt/symantec/sbas/Scanner/Brightmail_Scanner_InstallLog.log 2>&1 | grep '234 SUCCESSES' 2>&1`" = '234 SUCCESSES' ] ; then 
   echo 'Contents of bmiconfig.xml for local Scanner:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/Scanner/etc/bmiconfig.xml >>sadiag.txt 2>/dev/null
   echo ' ' >>sadiag.txt 2>&1   
   echo 'Contents of agentconfig.xml for local Scanner:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/Scanner/etc/agentconfig.xml >>sadiag.txt 2>/dev/null
   echo ' ' >>sadiag.txt 2>&1
   echo 'Contents of sieve_script.txt for local Scanner:' >>sadiag.txt 2>&1
       cat /opt/symantec/sbas/Scanner/etc/sieve_script.txt >>sadiag.txt 2>/dev/null
   else
      echo ' Installation log(s) for SBAS6Scanner:' >>sadiag.txt 2>&1
      cat /opt/symantec/sbas/Scanner/Brightmail_Scanner_InstallLog.log >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
   fi
   fi
fi
echo "Results of $NetworkStatTool:" >>sadiag.txt 2>&1
   $NetworkStatTool >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1
if [ "`uname -s`" = "SunOS" ] ; then 
   echo 'All running processes:' >>sadiag.txt 2>&1
      ps -ef >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1   
   echo 'Last 1000 lines of system log' >>sadiag.txt 2>&1
      /usr/xpg4/bin/tail -n 1000 /var/log/syslog >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
   echo 'Last 1000 lines of /var/adm/messages' >>sadiag.txt 2>&1
      /usr/xpg4/bin/tail -n 1000 /var/adm/messages >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
   echo 'Last 1000 lines of /var/log/security.log' >>sadiag.txt 2>&1
      /usr/xpg4/bin/tail -n 1000 /var/log/security.log >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
   echo 'Contents of /var/log/dmesg:' >>sadiag.txt 2>&1
      dmesg >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1
   echo 'Last 1000 lines of the LiveUpdate log:' >>sadiag.txt 2>&1
      /usr/xpg4/bin/tail -n 1000 ${product_root}/LiveUpdate/Logs/lux.log  >>sadiag.txt 2>&1
else #same stuff,but for Mac/Linux
   echo 'All running processes:' >>sadiag.txt 2>&1
      ps ax >>sadiag.txt 2>&1
   echo ' ' >>sadiag.txt 2>&1   
   #echo 'Last 1000 lines of the daily log for SAV:' >>sadiag.txt 2>&1
	  #tail -n 1000 Library/Logs/SMac.log /var/symantec/sep/Logs/`date +%m%d%Y`.log >>sadiag.txt 2>/dev/null
   echo ' ' >>sadiag.txt 2>&1
#   echo 'Last 1000 lines of system log' >>sadiag.txt 2>&1
#      tail -n 1000 /var/log/syslog /var/log/system.log >>sadiag.txt 2>/dev/null
#   echo ' ' >>sadiag.txt 2>&1
#   echo 'Last 1000 lines of /var/log/messages' >>sadiag.txt 2>&1
#      tail -n 1000 /var/log/messages >>sadiag.txt 2>&1
#   echo ' ' >>sadiag.txt 2>&1
#   echo 'Last 1000 lines of /var/log/security.log' >>sadiag.txt 2>&1
#      tail -n 1000 /var/log/security.log >>sadiag.txt 2>&1
#   echo ' ' >>sadiag.txt 2>&1
   echo 'Contents of /var/log/dmesg:' >>sadiag.txt 2>&1
      dmesg >>"${diag_dir}/dmesg.txt" 2>&1
   echo ' ' >>sadiag.txt 2>&1
   if [ -f /Libary/Logs/LiveUpdateAdminUtility.log ] ; then 
      echo 'Last 1000 lines of LiveUpdateAdminUtility.log' >>sadiag.txt 2>&1
         tail -n 1000 /Library/Logs/LiveUpdateAdminUtility.log >>sadiag.txt 2>&1
      echo ' ' >>sadiag.txt 2>&1
   fi
#   echo 'Last 1000 lines of the LiveUpdate log:' >>sadiag.txt 2>&1
#      tail -n 1000 /opt/Symantec/LiveUpdate/liveupdt.log /Library/Application\ Support/Norton\ Solutions\ Support/LiveUpdate/liveupdt.log /opt/Symantec/SMSSMTP/logs/liveupdt.log*log >>sadiag.txt 2>/dev/null
fi #end of the tail-limited log collection
if [ -f /local/notesdata/notes.ini ] ; then
   echo ' ' >>sadiag.txt 2>&1   
   echo 'Contents of notes.ini:' >>sadiag.txt 2>&1
   cp /local/notesdata/notes.ini "${cfg_dir}/" >> sadiag.txt 2>&1
fi   
echo ' ' >>sadiag.txt 2>&1
echo ' ' >>sadiag.txt 2>&1

collectlogs

collectcfgs

procs="smcd \
	   "
for proc in $procs
do
	core ${proc}
done

#-------------------------------
#   Conclusion of script
#-------------------------------
tar_file_suffix="`uname -n`_`date +%Y-%b-%d_%k_%M_%S`"
echo ' '
echo "   Execution of sadiag is complete. Please send For_Symantec_${tar_file_suffix}._ar.bz2 to your technician." >> sadiag.txt
#zip -mqT -P password "For_Symantec_${tar_file_suffix}.zip" sadiag.txt >/dev/null 2>&1

mv sadiag.txt "${diag_dir}/"
tar -cjvf "For_Symantec_${tar_file_suffix}.tar.bz2" -C "${diag_dir}/" .

echo "   Execution of sadiag is complete. Please send For_Symantec_${tar_file_suffix}.tar.bz2 to your technician."

finish
