#!/bin/bash


if [[ ${0:0:1} != "/" ]] ; then
  CWD=$PWD/`dirname $0`
else
  CWD=`dirname $0`
fi
cd "$CWD"

FILENAME=`basename $0`

## funny: $(dirname ~/sepfl-uninstallation.log)/sepfl-uninstall.log is same as ~/sepfl-uninstall.log :)
LOG=$(dirname ~/sepfl-uninstall.log)/sepfl-uninstall.log
PACKAGE_LIST=(sep \
		sepap \
		sepui \
		sepjlu\
		)
PACKAGE_LIST_X64=(sep \
		sepap-x64 \
		sepui \
		sepjlu\
		)

MSG_AV_RM_BEGIN="Begin removing virus protection component"
MSG_AV_RM_END="Virus protection component removed successfully"
MSG_AV_RM_FAIL="Virus protection component failed to remove"
MSG_AP_RM_BEGIN="Begin removing Auto-Protect component"
MSG_AP_RM_END="Auto-Protect component removed successfully"
MSG_AP_RM_FAIL="Auto-Protect component failed to remove"
MSG_UI_RM_BEGIN="Begin removing GUI component"
MSG_UI_RM_END="GUI component removed successfully"
MSG_UI_RM_FAIL="GUI component failed to remove"
MSG_LU_RM_BEGIN="Begin removing LiveUpdate component"
MSG_LU_RM_END="LiveUpdate component removed successfully"
MSG_LU_RM_FAIL="LiveUpdate component failed to remove"


SYMC_ROOT_DIR="/opt/Symantec"
SEPFL_PROD_ROOT_DIR="unassigned"
PROD_ROOT_TMP_DIR="unassigned"


###############
# Name	      : export_prod_root_tmp_dir_envvar()

# Arguments   : na

# Description :
## - We had chosen directory defined by PROD_ROOT_TMP_DIR env variable for installing the product.
## install.sh script exports an environment variable named PROD_ROOT_TMP_DIR.
## - Exported variable PROD_ROOT_TMP_DIR is used while installation and uninstallation of SEPFL and JLU components.
## - Modifies globally defined (scope through the entire script) SEPFL_PROD_ROOT_DIR and PROD_ROOT_TMP_DIR variables.
## - All the children processes use this variable.
## - Same function has been written in install.sh script along with global definitions of SYMC_ROOT_DIR, SEPFL_PROD_ROOT_DIR,
## and PROD_ROOT_TMP_DIR (again, scope through the entire script). This's necessary in case uninstall.sh
## is invoked independenly (from /opt/Symantec/symantec_antivirus or /opt/Symantec/sep/symantec_antivirus directory) without using install.sh
## script, i.e., without install.sh -u.

# Assumptions : na

# Usage       :
# export_prod_root_tmp_dir_envvar

# Return Value: default, i.e., 0
###############
export_prod_root_tmp_dir_envvar()
{
	SEPFL_PROD_ROOT_DIR=""$SYMC_ROOT_DIR"/sep"	## effective when /opt/Symantec/sep directory place-holder for SEPFL is created.
	PROD_ROOT_TMP_DIR=""$SEPFL_PROD_ROOT_DIR"/tmp"
	if [ ! -d "$SEPFL_PROD_ROOT_DIR" ] ; then
		PROD_ROOT_TMP_DIR=""$SYMC_ROOT_DIR"/tmp"
	fi

	export PROD_ROOT_TMP_DIR

	return 0
}


preUninstall()
{
	local tmpUninstallDir="/tmp"

	cp -f "${CWD}/${FILENAME}" "${tmpUninstallDir}/${FILENAME}" >> ${LOG} 2>&1

	if [ ! -f "${tmpUninstallDir}/${FILENAME}" ] ; then
		writeLog "Failed to copy the \"${CWD}/${FILENAME}\" to \"${tmpUninstallDir}/${FILENAME}\""
		return 1
	fi

	#launch the uninstall.sh in tmp folder
	${tmpUninstallDir}/${FILENAME} --uninstall

	local ret=$?

	rm -f "${tmpUninstallDir}/${FILENAME}" >> ${LOG} 2>&1

	return ${ret}
}

beginRm()
{
	local module="$1"

	case ${module} in
		sep)	writeLog "${MSG_AV_RM_BEGIN}" ;;
		sepap)	writeLog "${MSG_AP_RM_BEGIN}" ;;
		sepap-x64)	writeLog "${MSG_AP_RM_BEGIN}" ;;
		sepui)	writeLog "${MSG_UI_RM_BEGIN}" ;;
		sepjlu) writeLog "${MSG_LU_RM_BEGIN}" ;;

	esac

	return 0
}

endRm()
{
	local module="$1"

	case ${module} in
		sep)	writeLog "${MSG_AV_RM_END}" ;;
		sepap)	writeLog "${MSG_AP_RM_END}" ;;
		sepap-x64)	writeLog "${MSG_AP_RM_END}" ;;
		sepui)	writeLog "${MSG_UI_RM_END}" ;;
		sepjlu) writeLog "${MSG_LU_RM_END}" ;;

	esac

	return 0
}

failRm()
{
	local module="$1"
	local err="$2"

	case ${module} in
		sep)	writeLog "${MSG_AV_RM_FAIL}, error: ${err}" ;;
		sepap)	writeLog "${MSG_AP_RM_FAIL}, error: ${err}" ;;
		sepap-x64)	writeLog "${MSG_AP_RM_FAIL}, error: ${err}" ;;
		sepui)	writeLog "${MSG_UI_RM_FAIL}, error: ${err}" ;;
		sepjlu) writeLog "${MSG_LU_RM_FAIL}, error: ${err}" ;;

	esac

	return 0
}


IsRpmSupported()
{
	which rpm > /dev/null 2>&1
	if [ ! 0 -eq $? ] ; then
		return 0
	fi

	rpm -qa | grep rpm > /dev/null 2>&1

	if [ 0 -eq $? ]; then
		return 1
	fi

	return 0
}

IsPlatformX64()
{
	uname -m | grep i686 > /dev/null 2>&1
	if [ 0 -eq $? ]; then
		return 0
	fi

	return 1
}

writeLog()
{
	echo "$1" 2>&1 | tee -a ${LOG}
	return 0
}


selinuxSupport()
{
	which chcon > /dev/null 2>&1
	if [ ! 0 -eq $? ] ; then
		writeLog "chcon is not installed, skip setting selinux attribute."
		return 0
	fi

	if [ "${PREFIX}" != "" ] ; then
		dir="${PREFIX}/symantec_antivirus"
	else
		dir=/opt/Symantec/symantec_antivirus
	fi

	chcon -R -t texrel_shlib_t $dir >> "${LOG}" 2>&1

	status=$(service smcd status 2>&1)

	if [ "$status" != "smcd is running" ] ; then
		service smcd start 2>&1 | tee -a "${LOG}"
	fi

	return 0
}

prerm()
{
	#remove soft link of kernel drivers under /lib/modules/kernelversion/kernel/drivers/char
	#for all Kernel versions on the machine this is possible when multiple kernel versions are installed.
	local kerneldir="/lib/modules/*/kernel/drivers/char"
	local symap=$(ls $kerneldir/symap* 2>/dev/null | xargs)
	local symev=$(ls $kerneldir/symev* 2>/dev/null | xargs)
        local symevrm=$(ls $kerneldir/-symevrm* 2>/dev/null | xargs)

	for ap in $symap
	do
		echo "remove $ap" >> "${LOG}"
		rm -f $ap >> "${LOG}" 2>&1
	done

	for ev in $symev
	do
		echo "remove $ev" >> "${LOG}"
		rm -f $ev >> "${LOG}" 2>&1
	done

	for evrm in $symevrm
	do
		echo "remove $evrm" >> "${LOG}"
		rm -f $evrm >> "${LOG}" 2>&1
	done
}


postrm()
{
	#remove avdefs group.
	groupdel avdefs >> ${LOG} 2>&1

	#remove some the remaining folders
	local basedir=$(getBaseDir)
	if [ "${basedir}" = "" ] ; then
		basedir="/opt/Symantec"
	fi

	if [ -d "${basedir}/virusdefs" ] ; then
		rm -rf "${basedir}/virusdefs"
	fi

	[ -d "${basedir}/sep" ] && rm -fr "${basedir}/sep"
	[ -d "${basedir}/tmp" ] && rm -fr "${basedir}/tmp"
}

UninstallDeb()
{
	num=${#PACKAGE_LIST[@]}
	local failnum=0
	for ((i=1; i<=${num};i++));
	do
		idx=$(($num - $i))
		pa=${PACKAGE_LIST[$idx]}

		dpkg -s ${pa} > /dev/null 2>&1
		if [ ! 0 -eq $? ] ; then
			echo "${pa} has not been installed yet." >> ${LOG}
			continue
		fi

		beginRm "${pa}"
		dpkg -P ${pa} | tee -a "${LOG}"
		if [ 0 -eq $? ] ; then
			endRm "${pa}"
			continue;
		fi

		failRm "${pa}" "$?"
		failnum=$((failnum +1))
	done

	if [ $failnum -eq 0 ] ; then
		echo "Perform post uninstall operations" >> ${LOG}
		postrm
		echo "Post uninstall operations finished" >> ${LOG}
	fi

	return 0
}

UninstallRpm()
{
	local num
	local isX64=0
	IsPlatformX64
	isX64=$?
	if [ ${isX64} -eq 1 ] ; then
		#x86_64
		num=${#PACKAGE_LIST_X64[@]}
	else
		#i386
		num=${#PACKAGE_LIST[@]}
	fi

	local failnum=0
	for ((i=1;i<=${num};i++))
	do
		idx=$(($num - $i))

		if [ ${isX64} -eq 1 ] ; then
			#x86_64
			pa=${PACKAGE_LIST_X64[$idx]}
		else
			#i386
			pa=${PACKAGE_LIST[$idx]}
		fi

		rpm -qa ${pa} | grep ${pa} > /dev/null 2>&1
		if [ 0 -eq $? ] ; then
			beginRm "${pa}"
			rpm -e ${pa} | tee -a "${LOG}"
			if [ 0 -eq $? ] ; then
				endRm "${pa}"
			else
				failRm "${pa}" "$?"
				failnum=$((failnum + 1))
			fi
		else
			echo "The package ${pa} has not been installed yet." >> ${LOG}
		fi
	done

	if [ $failnum -eq 0 ] ; then
		echo "Perform post uninstall operations" >> ${LOG}
		postrm
		echo "Post uninstall operations finished" >> ${LOG}
	fi

	return 0
}

getBaseDir()
{
	if [ ! -f /etc/Symantec.conf ] ; then
		echo ""
		return 1
	fi

	local dir=$(cat /etc/Symantec.conf | grep BaseDir | awk -F'=' '{print $2}')
	echo $dir
	return 0
}

uninstall()
{
	datetime=$(date)
	echo "Starting to uninstall Symantec Endpoint Protection for Linux"
	echo "$datetime Starting to uninstall Symantec Endpoint Protection for Linux" >> "${LOG}"

	prerm
	IsRpmSupported
	if [ 0 -eq $? ] ; then
		UninstallDeb
		datetime=$(date)
		echo "Uninstallation completed"
		echo "$datetime Uninstallation completed" >> "${LOG}"
		return $?
	fi
	UninstallRpm
	datetime=$(date)
	echo "Uninstallation completed"
	echo "$datetime Uninstallation completed" >> "${LOG}"
	return $?
}

usage()
{
	echo "Usage: uninstall.sh"
	return 0
}

prepareLog()
{
	if [ -f ${LOG} ] ; then
		mv -f "${LOG}" "${LOG}.$$"
	fi

	return 0
}


###############
# Name	      : checkRunningEnv()

# Arguments   : na

# Description :
# - Identifies the effective user ID of the user who's executing the script.
# - Only root user (id 0) is allowed to execute the uninstall.sh script.

# Assumptions : na

# Usage       :
# checkRunningEnv

# Return Value:
## 0: if effective user ID of the user who's executing the script is "root" user.
## 1: otherwise.
###############
checkRunningEnv()
{
	local owner="$USER"
	local user_id="$(id -u)"

	if [ "$user_id" -ne 0 ] ; then	## user isn't the "root" user.
		writeLog "Current user is $owner, only superuser is permitted to execute this script. Please logon as a superuser and try again."
		return 1
	fi

	return 0
}


## main() starts here:
prepareLog
checkRunningEnv
if [ $? -ne 0 ] ; then
	exit $?
fi

while [ "$1" != "" ] ; do
	case $1 in
		-u | --uninstall)
			## - Exports PROD_ROOT_TMP_DIR variable to make it a part of current environment.
			## - All the children processes use this variable.
			## - Same function has been written in install.sh script.
			## - This function has been written in uninstall.sh in case uninstall is invoked without
			## using install.sh script, i.e., without install.sh -u.
			export_prod_root_tmp_dir_envvar
			echo "Exported env variable PROD_ROOT_TMP_DIR: $PROD_ROOT_TMP_DIR" >> "${LOG}"

			uninstall
			exit $?
			;;
		*)
			usage
			exit 0
			;;
	esac

	shift
done

echo "Are you sure to remove SEP for Linux from your machine?"
echo -e "\033[31mWARNING: After SEP for Linux is removed, your machine will not be protected.\033[0m"
echo "Do you want to remove SEP for Linux? Y[es]|N[o]: N"

read opt
opt=$(echo "$opt" | tr [A-Z] [a-z])
if [ "$opt" = "yes" -o "$opt" = "y" ] ; then
	preUninstall
	ret=$?
fi

writeLog "The log file for uninstallation of Symantec Endpoint Protection for Linux is under: ${LOG}"

exit ${ret}
