#!/bin/bash

#default path for savfl.
savfl_dir=/opt/Symantec/symantec_antivirus
lureg=luschedulereg
lunewreg=luregdata.inf

caconfigreg=caconfigreg
caconfignewreg=caconfigreg.inf

from_major=1
from_minor=0
enabled=1
frequency_none=0
frequency_daily=1
frequency_weekly=2
frequency_monthly=3

default_enabled=1
default_type=2
default_dayofweek=5
default_minofday=1200

log=$(dirname ~/sepfl-upgrade.log)/sepfl-upgrade.log

#$1 key name, such as Type
getPatternManagerScheduleValue()
{
	local symcfg=${savfl_dir}/symcfg
	local key="$1"
	local datafile=${savfl_dir}/${lureg}
	cat $datafile | grep Schedule[\\]$key | awk -F'\t' '{print $2}'
}

#$1 key name, such as Type
getCABundleValue()
{
	local symcfg=${savfl_dir}/symcfg
	local key="$1"
	local datafile=${savfl_dir}/${caconfigreg}
	cat $datafile | grep $key | awk -F'\t' '{print $2}'
}

importlureg=${savfl_dir}/${lunewreg}
importcareg=${savfl_dir}/${caconfignewreg}

rm -f $importlureg
rm -f $importcareg

echo "`date` Lu migration starts" >> $log

if [ ! -f ${savfl_dir}/${lureg} ] ; then
	echo "${savfl_dir}/${lureg} doesn't exist, skip lu migrate." >> $log
	exit 0
fi

if [ ! -f ${savfl_dir}/${caconfigreg} ] ; then
	echo "${savfl_dir}/${caconfigreg} doesn't exist, skip ca migrate." >> $log
fi

enabled=$(getPatternManagerScheduleValue Enabled)
type=$(getPatternManagerScheduleValue Type)
dayofweek=$(getPatternManagerScheduleValue DayOfWeek)
dayofmonth=$(getPatternManagerScheduleValue DayOfMonth)
minofday=$(getPatternManagerScheduleValue MinofDay)

cabundlepath=$(getCABundleValue CABundlePath)
cabundlefile=$(getCABundleValue CABundleFile)

if [ "x$cabundlepath" != "x" -o "x$cabundlefile" != "x" ] ; then
	echo "Restoring CA Certificate store to reg" >> $log
        echo "!KEY!=Symantec Endpoint Protection" >> $importcareg
        echo "CABundlePath=S$cabundlepath" >> $importcareg
        echo "CABundleFile=S$cabundlefile" >> $importcareg
fi

if [ "" = "$dayofweek" ] ; then
	dayofweek=0
fi

if [ "" = "$dayofmonth" ] ; then
	dayofmonth=0
fi

if [ "" = "$minofday" ] ; then
	minofday=0
fi

echo "the lu schdule contains customized configuration, need migrate it." >> $log

echo "!KEY!=Symantec Endpoint Protection\\LiveUpdate" >> $importlureg
echo "Enabled3rdPartyManagement=D0" >> $importlureg
echo "LiveUpdateServerType=D0" >> $importlureg
echo "UseLiveUpdateServer=D1" >> $importlureg
echo "UseManagementServer=D0" >> $importlureg
echo "UseMasterClient=D0" >> $importlureg
echo "HttpEncrypt=D0" >> $importlureg
echo "HttpProxyMode=D0" >> $importlureg
echo "FtpEncrypt=D0" >> $importlureg
echo "FtpProxyMode=D0" >> $importlureg
echo "AllowLocalScheduleChange=D0" >> $importlureg
echo "AllowManualLiveUpdate=D1" >> $importlureg
echo "EnableProductUpdates=D0" >> $importlureg

echo "!KEY!=Symantec Endpoint Protection\\LiveUpdate\\Schedule" >> $importlureg


if [ $enabled -eq ${default_enabled} -a $type -eq ${default_type} \
	   -a $dayofweek -eq ${default_dayofweek} \
	   -a $minofday -eq ${default_minofday} ] ; then
	   echo "the lu schedule contains default configuration in former build, use default one." >> $log
	   echo "Enabled=D1" >> $importlureg
	   echo "Type=D4" >> $importlureg
	   echo "FrequencyInterval=D240" >> $importlureg
	   echo "AllowRetry=D1" >> $importlureg
	   echo "RetryWindow=D120" >> $importlureg
	   echo "RandomizeEnabled=D0" >> $importlureg
	   exit 0
fi

#check that whether schedule is disabled or not.
if [ $enabled -eq 0 ] ; then
	echo "Enabled=D0" >> $importlureg
	echo "disable the lu schedule." >> $log
	exit 0
fi

echo "Enabled=D1" >> $importlureg
echo "enable the lu schdule." >> $log

#daily schedule.
#default retry time is 2 hours.
#default time window is 8 hours.
if [ $type -eq ${frequency_daily} ] ; then
	echo "Type=D1" >> $importlureg
	echo "set lu schedule type to daily." >> $log
	
	echo "MinOfDay=D${minofday}" >> $importlureg
	echo "AllowRetry=D1" >> $importlureg
	echo "RetryWindow=D120" >> $importlureg
	echo "RandomizeEnabled=D0" >> $importlureg
	echo "succeed to migrate lu schedule configuration." >> $log
	exit 0
fi

if [ $type -eq ${frequency_weekly} ] ; then
	echo "Type=D2" >> $importlureg
	echo "set lu schedule type to weekly." >> $log

	echo "DayOfWeek=D${dayofweek}" >> $importlureg
	echo "MinOfDay=D${minofday}" >> $importlureg
	echo "AllowRetry=D1" >> $importlureg
	echo "RetryWindow=D2880" >> $importlureg
	echo "RandomizeEnabled=D0" >> $importlureg
	echo "succeed to migrate lu schedule configuration." >> $log
	exit 0
fi

if [ $type -eq ${frequency_monthly} ] ; then
	echo "Type=D2" >> $importlureg
	echo "convert lu schedule type from monthly to weekly." >> $log

	#get the dayofweek.
	this_month=$(date +%m)
	this_year=$(date +%Y)
	dayofweek=$(date -d "${this_month}/${dayofmonth}/${this_year}" +%u)
	
	echo "DayOfWeek=D${dayofweek}" >> $importlureg
	echo "MinOfDay=D${minofday}" >> $importlureg
	echo "AllowRetry=D1" >> $importlureg
	echo "RetryWindow=D2880" >> $importlureg
	echo "RandomizeEnabled=D0" >> $importlureg
	echo "succeed to migrate lu schedule configuration." >> $log
	exit 0
fi
